from .http import *
sfw_tags = ["all", "husbando", "waifu"]
nsfw_tags = ["ass", "ecchi", "ero", "hentai", "maid", "milf", "oppai", "oral", "paizuri", "selfies", "uniform"]
async def sfw(tag):
    if tag in sfw_tags:
        session = await session_json(F"https://api.hori.ovh/sfw/{tag}/")
        return session
    print(F"There is no {tag} tag\nConsider using:\n{sfw_tags} tags")

async def nsfw(tag):
    if tag in nsfw_tags:
        session = await session_json(F"https://api.hori.ovh/nsfw/{tag}/")
        return session
    print(F"There is no {tag} tag\nConsider using:\n{nsfw_tags} tags")



import aiohttp, io, json
async def session_bytes(url, headers=None):
    async with aiohttp.ClientSession() as session:
        async with session.get(url, headers=headers) as r:
            data = io.BytesIO(await r.read())
            return data
async def session_json(url, headers=None):
    async with aiohttp.ClientSession() as session:
        async with session.get(url, headers=headers) as r:
            return await r.json()
async def session_text(url, headers=None):
    async with aiohttp.ClientSession() as session:
        async with session.get(url, headers=headers) as r:
            return json.loads((await r.text()))


import setuptools
import discord
requirements = []
with open('requirements.txt') as f:
  requirements = f.read().splitlines()

with open("README.md", "r") as fh:
    long_description = fh.read()

extras_require = {
    "http": ["aiohttp", "async-timeout", "typing-extensions", "multidict", "attrs", "yarl", "chardet"]
}
setuptools.setup(
  name='aiohoripy',
  author='lvlahraam',
  url='https://github.com/lvlahraam/aiohoripy',
  version="0.0.2",
  license='MIT',
  description='An asynchronous Python Wrapper for Hori-API',
  long_description=long_description,
  long_description_content_type="text/markdown",
  python_requires='>=3.8.0',
  packages=setuptools.find_packages(),
  include_package_data=True,
  install_requires=[
    "aiohttp",
    "async-timeout",
    "typing-extensions",
    "multidict",
    "attrs",
    "yarl",
    "chardet"
  ],
  keywords=["python", "api", "discord", "http", "anime", "hori"],
  classifiers=[
    'Development Status :: 5 - Production/Stable',
    'License :: OSI Approved :: MIT License',
    'Intended Audience :: Developers',
    'Natural Language :: English',
    'Operating System :: OS Independent',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Topic :: Internet',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Internet :: WWW/HTTP :: HTTP Servers',
    'Topic :: Internet :: WWW/HTTP :: Session',
    'Topic :: Software Development :: Libraries',
    'Topic :: Software Development :: Libraries :: Python Modules',
    'Topic :: Utilities',
    'Typing :: Typed',
  ]
)